import {
  Component,
  Input,
  Output,
  EventEmitter,
  ElementRef,
  ChangeDetectionStrategy,
} from '@angular/core';
import { CommonModule } from '@angular/common';
import { AnimationService } from '../../../services/animation.service';

@Component({
  selector: 'app-animated-button',
  standalone: true,
  imports: [CommonModule],
  template: `
    <button
      (click)="handleClick($event)"
      [class]="buttonClass"
      [ngClass]="size === 'large' ? 'px-12 py-5 text-2xl' : 'px-8 py-3 text-sm'"
    >
      <div
        class="absolute inset-0 rounded-full bg-white/20 opacity-0 group-hover:opacity-100 transition-all duration-500 ease-in-out"
      ></div>
      <span class="relative z-10 group-hover:tracking-wider transition-all duration-300">
        <ng-content></ng-content>
      </span>
    </button>
  `,
  styles: [],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class AnimatedButtonComponent {
  @Input() variant: 'primary' | 'secondary' = 'primary';
  @Input() size: 'normal' | 'large' = 'normal';
  @Output() buttonClick = new EventEmitter<MouseEvent>();

  constructor(private animationService: AnimationService) {}

  get buttonClass(): string {
    const baseClass =
      'cursor-pointer relative group font-bold rounded-full transition-all duration-300 ease-out transform-gpu hover:scale-105 will-change-transform';
    const variantClass =
      this.variant === 'primary'
        ? 'bg-gradient-to-r from-emerald-500 to-emerald-400 text-black hover:shadow-xl hover:shadow-emerald-500/20'
        : 'bg-white/10 text-white hover:bg-white/20';

    return `${baseClass} ${variantClass}`;
  }

  handleClick(event: MouseEvent): void {
    const elementRef = new ElementRef(event.currentTarget);
    this.animationService.animateButtonClick(elementRef);
    this.buttonClick.emit(event);
  }
}
